API docs for “spamfighter.core.commands.test.test_command.CommandTestCase”

# Class s.c.c.t.t.CommandTestCase(unittest.TestCase):

Part of spamfighter.core.commands.test.test_command View Source View In Hierarchy

Тест на `spamfighter.core.commands.command.Command`.

Тестируем базовую функциональность команды.

Method | setUp | Undocumented
Method | testParams | Undocumented
Method | testCompleteness | Undocumented
Method | testType | Undocumented
Method | testSerialize | Undocumented
Method | testSerializeComplex | Undocumented
Method | testSerializeComplexArray | Undocumented

def setUp(self): (source)
Undocumented
def testParams(self): (source)
Undocumented
def testCompleteness(self): (source)
Undocumented
def testType(self): (source)
Undocumented
def testSerialize(self): (source)
Undocumented
def testSerializeComplex(self): (source)
Undocumented
def testSerializeComplexArray(self): (source)
Undocumented